@@ -153,6 +153,7 @@ col_vals_lte <- function(x,
                          preconditions = NULL,
                          actions = NULL,
                          step_id = NULL,
+                         label = NULL,
                          brief = NULL,
                          active = TRUE) {
   
@@ -170,6 +171,7 @@ col_vals_lte <- function(x,
         value = value,
         na_pass = na_pass,
         preconditions = preconditions,
+        label = label,
         brief = brief,
         actions = prime_actions(actions),
         active = active
@@ -205,6 +207,7 @@ col_vals_lte <- function(x,
         preconditions = preconditions,
         actions = covert_actions(actions, agent),
         step_id = step_id[i],
+        label = label,
         brief = brief[i],
         active = active
       )
