@@ -68,7 +68,7 @@ print.x_list_i <- function(x, ...) {
   cli::cli_text("{.cyan $name $tbl_name $tbl_src $tbl_src_details} ({.red chr [1]})")
   cli::cli_text("{.cyan $tbl} ({.blue {class(x$tbl)}})")
   cli::cli_text("{.cyan $col_names $col_types} ({.red chr [{length(x$col_names)}]})")
-  cli::cli_text("{.cyan $i $type $columns $values $briefs} ({.green mixed [{length(x$i)}]})")
+  cli::cli_text("{.cyan $i $type $columns $values $label $briefs} ({.green mixed [{length(x$i)}]})")
   cli::cli_text("{.cyan $eval_error $eval_warning} ({.yellow lgl [{length(x$i)}]})")
   cli::cli_text("{.cyan $capture_stack} ({.orange list [{length(x$capture_stack)}]})")
   cli::cli_text("{.cyan $n $n_passed $n_failed $f_passed $f_failed} ({.green num [{length_rows}]})")
@@ -115,7 +115,7 @@ print.x_list_n <- function(x, ...) {
   cli::cli_text("{.cyan $name $tbl_name $tbl_src $tbl_src_details} ({.red chr [1]})")
   cli::cli_text("{.cyan $tbl} ({.blue {class(x$tbl)}})")
   cli::cli_text("{.cyan $col_names $col_types} ({.red chr [{length(x$col_names)}]})")
-  cli::cli_text("{.cyan $i $type $columns $values $briefs} ({.green mixed [{length(x$i)}]})")
+  cli::cli_text("{.cyan $i $type $columns $values $label $briefs} ({.green mixed [{length(x$i)}]})")
   cli::cli_text("{.cyan $eval_error $eval_warning} ({.yellow lgl [{length(x$i)}]})")
   cli::cli_text("{.cyan $capture_stack} ({.orange list [{length(x$capture_stack)}]})")
   cli::cli_text("{.cyan $n $n_passed $n_failed $f_passed $f_failed} ({.green num [{length_rows}]})")
