@@ -15,7 +15,7 @@ test_that("Getting an agent report is possible", {
   # Expect that the report has specific column names
   expect_equivalent(
     colnames(report),
-    c("i", "type", "columns", "value", "set", "regex", "preconds",
+    c("i", "type", "columns", "values", "precon", "active", "eval",
       "units", "n_pass", "f_pass", "W", "S", "N", "extract")
   )
   
@@ -25,17 +25,15 @@ test_that("Getting an agent report is possible", {
   # Expect certain column types for this report
   expect_is(report$type, "character")
   expect_is(report$columns, "character")
-  expect_is(report$value, "numeric")
-  expect_is(report$set, "character")
-  expect_is(report$regex, "character")
-  expect_is(report$preconds, "logical")
+  expect_is(report$values, "character")
+  expect_is(report$precon, "character")
   expect_is(report$units, "numeric")
   expect_is(report$n_pass, "numeric")
   expect_is(report$f_pass, "numeric")
   expect_is(report$W, "logical")
   expect_is(report$S, "logical")
   expect_is(report$N, "logical")
-  expect_is(report$extract, "logical")
+  expect_is(report$extract, "integer")
   
   
   agent_report_empty <-
@@ -46,10 +44,8 @@ test_that("Getting an agent report is possible", {
   # Expect certain values in the single row report
   expect_equal(agent_report_empty$type, "col_is_character")
   expect_equal(agent_report_empty$columns, "b")
-  expect_equal(agent_report_empty$value, NA_real_)
-  expect_equal(agent_report_empty$set, NA_character_)
-  expect_equal(agent_report_empty$regex, NA_character_)
-  expect_equal(agent_report_empty$preconds, FALSE)
+  expect_equal(agent_report_empty$values, NA_character_)
+  expect_equal(agent_report_empty$precon, NA_character_)
   expect_equal(agent_report_empty$units, NA_integer_)
   expect_equal(agent_report_empty$n_pass, NA_integer_)
   expect_equal(agent_report_empty$f_pass, NA_real_)
